==> GlassConfigAPI-3.0.0-sources.jar: net/glasslauncher/mods/gcapi3/api/GCAPI.java <==
package net.glasslauncher.mods.gcapi3.api;

import net.glasslauncher.mods.gcapi3.impl.ConfigRootEntry;
import net.glasslauncher.mods.gcapi3.impl.EventStorage;
import net.glasslauncher.mods.gcapi3.impl.GCCore;
import net.glasslauncher.mods.gcapi3.impl.GlassYamlFile;
import net.glasslauncher.mods.gcapi3.impl.screen.RootScreenBuilder;
import net.minecraft.class_32;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.management.*;
import java.io.*;

/**
 * Use this instead of GCCore!
 */
@SuppressWarnings("deprecation")
public class GCAPI {

    /**
     * Force a config reload, or load your own config json! Can be partial.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     * @param overrideConfigJson Optional config override JSON. Leave as null to do a plain config reload. JSON can be partial, and missing values from the JSON will be kept.
     */
    public static void reloadConfig(String configID, @Nullable String overrideConfigJson) throws IOException {
        reloadConfig(configID, new GlassYamlFile(overrideConfigJson));
    }

    /**
     * Force a config reload, or load your own config json! Can be partial.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     * @param overrideConfigJson Optional config override JSON. Leave as null to do a plain config reload. JSON can be partial, and missing values from the JSON will be kept.
     */
    public static void reloadConfig(String configID, @Nullable GlassYamlFile overrideConfigJson) {
        ConfigRootEntry category = GCCore.MOD_CONFIGS.get(configID);
        GCCore.loadModConfig(category.configRoot(), category.modContainer(), category.configCategoryHandler().parentField, configID, overrideConfigJson);
        GCCore.saveConfig(category.modContainer(), category.configCategoryHandler(), EventStorage.EventSource.MOD_SAVE);
    }

    /**
     * Force a config reload.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     */
    public static void reloadConfig(String configID) {
        reloadConfig(configID, (GlassYamlFile) null);
    }

    public static RootScreenBuilder getRootConfigScreen(@NotNull String identifier, class_32 parent) throws AttributeNotFoundException {
        ConfigRootEntry configRootEntry = GCCore.MOD_CONFIGS.get(identifier);
        if (configRootEntry != null) {
            return new RootScreenBuilder(parent, configRootEntry.modContainer(), configRootEntry.configCategoryHandler());
        }
        else {
            throw new AttributeNotFoundException(); // Probably the wrong error. Whatever.
        }
    }

}

==> GlassConfigAPI-3.2.1-sources.jar: net/glasslauncher/mods/gcapi3/api/GCAPI.java <==
package net.glasslauncher.mods.gcapi3.api;

import net.glasslauncher.mods.gcapi3.impl.ConfigRootEntry;
import net.glasslauncher.mods.gcapi3.impl.EventStorage;
import net.glasslauncher.mods.gcapi3.impl.GCCore;
import net.glasslauncher.mods.gcapi3.impl.GlassYamlFile;
import net.glasslauncher.mods.gcapi3.impl.screen.RootScreenBuilder;
import net.minecraft.class_32;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.management.AttributeNotFoundException;
import java.io.IOException;

/**
 * Use this instead of GCCore!
 */
@SuppressWarnings("deprecation")
public class GCAPI {

    /**
     * Force a config reload, or load your own config json! Can be partial.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     * @param overrideConfigJson Optional config override JSON. Leave as null to do a plain config reload. JSON can be partial, and missing values from the JSON will be kept.
     */
    public static void reloadConfig(String configID, @Nullable String overrideConfigJson) throws IOException {
        reloadConfig(configID, new GlassYamlFile(overrideConfigJson));
    }

    /**
     * Force a config reload, or load your own config json! Can be partial.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     * @param overrideConfigJson Optional config override JSON. Leave as null to do a plain config reload. JSON can be partial, and missing values from the JSON will be kept.
     */
    public static void reloadConfig(String configID, @Nullable GlassYamlFile overrideConfigJson) {
        ConfigRootEntry category = GCCore.MOD_CONFIGS.get(configID);
        GCCore.loadModConfig(category.configRoot(), category.modContainer(), category.configCategoryHandler().parentField, configID, overrideConfigJson);
        GCCore.saveConfig(category.modContainer(), category.configCategoryHandler(), EventStorage.EventSource.MOD_SAVE);
    }

    /**
     * Force a config reload.
     * @param configID Should be an identifier formatted like mymodid:mygconfigvalue
     */
    public static void reloadConfig(String configID) {
        reloadConfig(configID, (GlassYamlFile) null);
    }

    public static RootScreenBuilder getRootConfigScreen(@NotNull String identifier, class_32 parent) throws AttributeNotFoundException {
        ConfigRootEntry configRootEntry = GCCore.MOD_CONFIGS.get(identifier);
        if (configRootEntry != null) {
            return new RootScreenBuilder(parent, configRootEntry.modContainer(), configRootEntry.configCategoryHandler());
        }
        else {
            throw new AttributeNotFoundException(); // Probably the wrong error. Whatever.
        }
    }

}
